@@ -47,7 +47,7 @@ class Service(object):
             service_name,
             api_version=None
         )
-        self._model = ServiceModel(sdata)
+        self._model = session.get_service_model(service_name)
         self.__dict__.update(sdata)
         self._operations_data = self.__dict__.pop('operations')
         self._operations = None
@@ -65,6 +65,7 @@ class Service(object):
         # as an attribute for client obejcts.
         self.service_name = service_name
         self._signature_version = NOT_SET
+        self._has_custom_signature_version = False
         # Not all services have a top level documentation key,
         # so we'll add one if needed.
         if 'documentation' not in self.__dict__:
@@ -99,11 +100,13 @@ class Service(object):
         if self._signature_version is NOT_SET:
             signature_version = self._model.metadata.get('signatureVersion')
             self._signature_version = signature_version
+            self._has_custom_signature_version = False
         return self._signature_version
 
     @signature_version.setter
     def signature_version(self, value):
         self._signature_version = value
+        self._has_custom_signature_version = True
 
     def _create_operation_objects(self):
         logger.debug("Creating operation objects for: %s", self)
@@ -151,13 +154,21 @@ class Service(object):
         resolver = self.session.get_component('endpoint_resolver')
         region = self.session.get_config_variable('region')
         event_emitter = self.session.get_component('event_emitter')
+        response_parser_factory = self.session.get_component(
+            'response_parser_factory')
         model = self._model
         credentials = self.session.get_credentials()
         user_agent= self.session.user_agent()
         endpoint_creator = EndpointCreator(resolver, region, event_emitter,
                                            credentials, user_agent)
-        return endpoint_creator.create_endpoint(self._model, region_name, is_secure,
-                                                endpoint_url, verify)
+        kwargs = {'service_model': self._model, 'region_name': region_name,
+                  'is_secure': is_secure, 'endpoint_url': endpoint_url,
+                  'verify': verify,
+                  'response_parser_factory': response_parser_factory}
+        if self._has_custom_signature_version:
+            kwargs['signature_version'] = self.signature_version
+
+        return endpoint_creator.create_endpoint(**kwargs)
 
     def get_operation(self, operation_name):
         """
